<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ActivityWidget</name>
    <message>
        <location filename="../src/activitywidget.cpp" line="115"/>
        <source> via %1</source>
        <translation> über %1</translation>
    </message>
    <message>
        <location filename="../src/activitywidget.cpp" line="124"/>
        <source>To:</source>
        <translation>An:</translation>
    </message>
    <message>
        <location filename="../src/activitywidget.cpp" line="127"/>
        <source>CC:</source>
        <translation>CC:</translation>
    </message>
    <message>
        <location filename="../src/activitywidget.cpp" line="144"/>
        <source>Public</source>
        <translation>Öffentlich</translation>
    </message>
</context>
<context>
    <name>ActorWidget</name>
    <message>
        <location filename="../src/actorwidget.cpp" line="137"/>
        <source>stop following</source>
        <translation>Nicht mehr folgen</translation>
    </message>
    <message>
        <location filename="../src/actorwidget.cpp" line="138"/>
        <source>follow</source>
        <translation>Folgen</translation>
    </message>
    <message>
        <location filename="../src/actorwidget.cpp" line="140"/>
        <source>stop minimising posts</source>
        <translation>Beiträge nicht mehr minimieren</translation>
    </message>
    <message>
        <location filename="../src/actorwidget.cpp" line="141"/>
        <source>auto-minimise posts</source>
        <translation>Beiträge automatisch minimieren</translation>
    </message>
    <message>
        <location filename="../src/actorwidget.cpp" line="149"/>
        <source>Are you sure you want to stop following %1?</source>
        <translation>Sind Sie sicher, dass Sie %1 nicht mehr folgen wollen?</translation>
    </message>
</context>
<context>
    <name>CollectionWidget</name>
    <message>
        <location filename="../src/collectionwidget.cpp" line="69"/>
        <source>Load older</source>
        <translation>Ältere Beiträge laden</translation>
    </message>
</context>
<context>
    <name>EditProfileDialog</name>
    <message>
        <location filename="../src/editprofiledialog.cpp" line="42"/>
        <source>&amp;Change picture</source>
        <translation>&amp;Bild ändern</translation>
    </message>
    <message>
        <location filename="../src/editprofiledialog.cpp" line="49"/>
        <source>Real name</source>
        <translation type="unfinished">Klarname</translation>
    </message>
    <message>
        <location filename="../src/editprofiledialog.cpp" line="55"/>
        <source>Hometown</source>
        <translation>Heimatstadt</translation>
    </message>
    <message>
        <location filename="../src/editprofiledialog.cpp" line="61"/>
        <source>Bio</source>
        <translation type="unfinished">Bio</translation>
    </message>
    <message>
        <location filename="../src/editprofiledialog.cpp" line="138"/>
        <source>Select Image</source>
        <translation>Bild auswählen</translation>
    </message>
    <message>
        <location filename="../src/editprofiledialog.cpp" line="139"/>
        <source>Image files (*.png *.jpg *.jpeg *.gif);;All files (*.*)</source>
        <translation>Bilddateien (*.png *.jpg *.jpeg *.gif);;Alle Dateien (*.*)</translation>
    </message>
    <message>
        <location filename="../src/editprofiledialog.cpp" line="147"/>
        <source>Sorry!</source>
        <translation>Entschuldigung!</translation>
    </message>
    <message>
        <location filename="../src/editprofiledialog.cpp" line="148"/>
        <source>That file didn&apos;t appear to be an image.</source>
        <translation>Die ausgewählte Datei scheint kein Bild zu sein.</translation>
    </message>
</context>
<context>
    <name>FileDownloader</name>
    <message>
        <location filename="../src/filedownloader.cpp" line="291"/>
        <source>Network error: </source>
        <translation>Netzwerkfehler: </translation>
    </message>
    <message>
        <location filename="../src/filedownloader.cpp" line="298"/>
        <source>Network error: too many redirections!</source>
        <translation>Netzwerkfehler: Zu viele Weiterleitungen!</translation>
    </message>
    <message>
        <location filename="../src/filedownloader.cpp" line="320"/>
        <source>Unable to download %1 (Error #%2).</source>
        <translation>Download von %1 nicht möglich (Fehler #%2).</translation>
    </message>
    <message>
        <location filename="../src/filedownloader.cpp" line="330"/>
        <source>Could not open file %1 for writing: </source>
        <translation>Datei %1 konnte nicht zum Schreiben geöffnet werden: </translation>
    </message>
</context>
<context>
    <name>FullObjectWidget</name>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="105"/>
        <source>delete</source>
        <translation>löschen</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="109"/>
        <source>edit</source>
        <translation>bearbeiten</translation>
    </message>
    <message>
        <source>comment</source>
        <translation type="vanished">kommentieren</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="113"/>
        <source>comment</source>
        <comment>Button to comment on a post</comment>
        <translation>kommentieren</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="313"/>
        <source>[No description]</source>
        <translation>[Keine Beschreibung]</translation>
    </message>
    <message>
        <source>at %1</source>
        <translation type="vanished">@ %1</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="349"/>
        <source>at %1</source>
        <comment>location of person</comment>
        <translation type="unfinished">in %1</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="351"/>
        <source>Profile last updated %1</source>
        <translation type="unfinished">Profil zuletzt aktualisiert @ %1</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="359"/>
        <source>updated %1</source>
        <translation>geändert %1</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="366"/>
        <source>at %1</source>
        <comment>time when post was published</comment>
        <translation type="unfinished">@ %1</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="386"/>
        <source>unlike</source>
        <translation type="unfinished">defavorisieren</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="386"/>
        <source>like</source>
        <translation type="unfinished">favorisieren</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="398"/>
        <source>share</source>
        <translation>teilen</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="423"/>
        <source>stop following</source>
        <translatorcomment>enfolge ist nicht das schönste Wort. Allerdings steht hinter dem stop following direkt der Nickname als z.B. &quot;stop following evan&quot;</translatorcomment>
        <translation>entfolge</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="424"/>
        <source>follow</source>
        <translation>folge</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="547"/>
        <source>shared this.</source>
        <comment>Many persons shared</comment>
        <translation>teilten das.</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="549"/>
        <source>shared this.</source>
        <comment>One person shared</comment>
        <translation>teilte das.</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="629"/>
        <source>Show all replies</source>
        <translation>Alle Kommentare anzeigen</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="673"/>
        <source>post</source>
        <comment>Name of object type.</comment>
        <translation>Beitrag</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="676"/>
        <source>note</source>
        <comment>Name of object type.</comment>
        <translation type="unfinished">Mitteilung</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="678"/>
        <source>comment</source>
        <comment>Name of object type.</comment>
        <translation>Kommentar</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="680"/>
        <source>image</source>
        <comment>Name of object type.</comment>
        <translation>Bild</translation>
    </message>
    <message>
        <source>stop following %1</source>
        <translation type="obsolete">%1 nicht mehr folgen</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="442"/>
        <source>follow %1</source>
        <translation>%1 folgen</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="512"/>
        <source>You like this.</source>
        <translation>Dir gefällt das.</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="514"/>
        <source>%1 likes this.</source>
        <translation>%1 gefällt das.</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="516"/>
        <source>%1 like this.</source>
        <translation>%1 gefällt das.</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/fullobjectwidget.cpp" line="545"/>
        <source>and %Ln other person(s)</source>
        <translation>
            <numerusform>und %Ln weitere Person</numerusform>
            <numerusform>und %Ln weiteren Personen</numerusform>
        </translation>
    </message>
    <message>
        <source>Are you sure you want to stop following %1?</source>
        <translation type="obsolete">Sind Sie sicher, dass Sie %1 nicht mehr folgen wollen?</translation>
    </message>
    <message numerus="yes">
        <source>%Ln persons shared this.</source>
        <translation type="obsolete">
            <numerusform>one person shared this.</numerusform>
            <numerusform>%n persons shared this.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>shared this.</source>
        <translation type="obsolete">
            <numerusform>teilten das.</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/fullobjectwidget.cpp" line="552"/>
        <source>%Ln person(s) shared this.</source>
        <translation type="unfinished">
            <numerusform>von %Ln Person geteilt.</numerusform>
            <numerusform>von %Ln Personen geteilt.</numerusform>
        </translation>
    </message>
    <message>
        <source>Show all %1 replies</source>
        <translation type="obsolete">alle %1 Antworten anzeigen</translation>
    </message>
    <message>
        <source>post</source>
        <translation type="vanished">Beitrag</translation>
    </message>
    <message>
        <source>note</source>
        <translation type="vanished">Mitteilung</translation>
    </message>
    <message>
        <source>image</source>
        <translation type="vanished">Bild</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="701"/>
        <source>Are you sure you want to delete this %1?</source>
        <translation>Sind Sie sicher, dass Sie %1 löschen wollen?</translation>
    </message>
    <message>
        <location filename="../src/fullobjectwidget.cpp" line="721"/>
        <source>Share this %1 by %2?</source>
        <translation>Diese(n) %1 von %2 teilen?</translation>
    </message>
    <message>
        <source>Are you sure you want to stop following</source>
        <translation type="obsolete">Sind Sie sicher, dass Sie dem Benutzer nicht mehr folgen wollen</translation>
    </message>
</context>
<context>
    <name>MessageEdit</name>
    <message>
        <location filename="../src/messageedit.cpp" line="192"/>
        <source>Spelling suggestions...</source>
        <translation>Rechtschreibvorschläge ...</translation>
    </message>
</context>
<context>
    <name>MessageRecipients</name>
    <message>
        <location filename="../src/messagerecipients.cpp" line="52"/>
        <source>-</source>
        <translation>-</translation>
    </message>
</context>
<context>
    <name>MessageWindow</name>
    <message>
        <location filename="../src/messagewindow.cpp" line="71"/>
        <source>Use Markdown</source>
        <translation>Markdown verwenden</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="76"/>
        <source>[help]</source>
        <translation>[Hilfe]</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="91"/>
        <source>To:</source>
        <translation>An:</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="92"/>
        <source>Cc:</source>
        <translation>Cc:</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="102"/>
        <source>&amp;Remove picture</source>
        <translation>Bild &amp;löschen</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="106"/>
        <source>+ &amp;To</source>
        <translation>+ &amp;An</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="109"/>
        <source>+ &amp;Cc</source>
        <translation>+ &amp;Cc</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="127"/>
        <source>Title (optional)</source>
        <translation>Titel (optional)</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="168"/>
        <source>Ca&amp;ncel</source>
        <translation>Abbreche&amp;n</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="171"/>
        <source>&amp;Preview</source>
        <translation>&amp;Vorschau</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="174"/>
        <source>&amp;Send message</source>
        <translation>Nachricht &amp;senden</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="306"/>
        <source>&amp;Send comment</source>
        <translation>Kommentar &amp;senden</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="306"/>
        <source>&amp;Send post</source>
        <translation>Beitrag &amp;senden</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="352"/>
        <source>Edit object</source>
        <translation>Objekt bearbeiten</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="355"/>
        <source>Edit post</source>
        <translation>Beitrag bearbeiten</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="357"/>
        <source>Edit comment</source>
        <translation>Kommentar bearbeiten</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="359"/>
        <source>Edit image post</source>
        <translation>Bildnachricht bearbeiten</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="361"/>
        <source>&amp;Update object</source>
        <translation>Objekt akt&amp;ualisieren</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="364"/>
        <source>&amp;Update post</source>
        <translation>Beitrag akt&amp;ualisieren</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="366"/>
        <source>&amp;Update comment</source>
        <translation>Kommentar akt&amp;ualisieren</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="368"/>
        <source>&amp;Update image post</source>
        <translation>Bildnachricht akt&amp;ualisieren</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="518"/>
        <source>Characters: %1</source>
        <translation>Zeichen: %1</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Abbrechen</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Vorschau</translation>
    </message>
    <message>
        <source>Send message</source>
        <translation type="obsolete">Mitteilung senden</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="245"/>
        <source>Select recipient (To)</source>
        <translation>Empfänger auswählen (An)</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="251"/>
        <source>Select recipient (Cc)</source>
        <translation>Empfänger auswählen (Cc)</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="305"/>
        <source>Post a note</source>
        <translation>Neue Mitteilung</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="305"/>
        <source>Post a reply</source>
        <translation>Antwort verfassen</translation>
    </message>
    <message>
        <source>Mentions:</source>
        <translation type="obsolete">Vorschläge:</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="451"/>
        <source>Select Image</source>
        <translation>Bild auswählen</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="452"/>
        <source>Image files (*.png *.jpg *.jpeg *.gif);;All files (*.*)</source>
        <translation>Bilddatei (*.png *.jpg *.jpeg *.gif);;Alle Dateien (*.*)</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="484"/>
        <source>Sorry!</source>
        <translation>Entschuldigung!</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="485"/>
        <source>That file didn&apos;t appear to be an image.</source>
        <translation>Die ausgewählte Datei scheint kein Bild zu sein.</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="493"/>
        <source>&amp;Add picture</source>
        <translation>&amp;Bild einfügen</translation>
    </message>
    <message>
        <location filename="../src/messagewindow.cpp" line="501"/>
        <source>&amp;Change picture</source>
        <translation>Bild &amp;ändern</translation>
    </message>
</context>
<context>
    <name>OAuthFirstPage</name>
    <message>
        <location filename="../src/oauthwizard.cpp" line="44"/>
        <source>Welcome to Pumpa!</source>
        <translation>Willkommen zu Pumpa!</translation>
    </message>
    <message>
        <location filename="../src/oauthwizard.cpp" line="49"/>
        <source>&lt;p&gt;In order to use pump.io you need to first register an account with a pump.io server. If you haven&apos;t done this yet you can do it now by trying out one of the existing public servers: &lt;br /&gt;&lt;a href=&quot;http://pump.io/tryit.html&quot;&gt;http://pump.io/tryit.html&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;When you are done enter your new pump.io account id below in the form of &lt;b&gt;username@servername&lt;/b&gt;.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Um pump.io nutzen zu können, benötigen Sie ein Konto auf einem pump.io-Server. Wenn Sie noch kein Konto besitzen, können Sie sich jetzt einfach an einem der öffentlichen pump.io-Server unter folgendem Link registrieren:&lt;/p&gt;
&lt;a href=&quot;http://pump.io/tryit.html&quot;&gt;http://pump.io/tryit.html&lt;/a&gt;&lt;p&gt;Wenn Sie ein Konto erstellt haben oder bereits ein pump.io-Konto besitzen, tragen Sie Ihre Konto-ID im Format &lt;b&gt;benutzername@servername&lt;/b&gt; unten ein.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/oauthwizard.cpp" line="68"/>
        <source>&lt;b&gt;Your pump.io account id:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ihre pump.io-Konto-ID:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/oauthwizard.cpp" line="75"/>
        <source>Use secure connection (recommended)</source>
        <translation>Sichere Verbindung verwenden (empfohlen)</translation>
    </message>
    <message>
        <location filename="../src/oauthwizard.cpp" line="85"/>
        <source>Next</source>
        <translatorcomment>&quot;Back&quot; ist leider nicht vorhanden. Daher macht es keinen Sinn nur Next mit Vor zu übersetzen</translatorcomment>
        <translation type="unfinished">Weiter</translation>
    </message>
</context>
<context>
    <name>OAuthSecondPage</name>
    <message>
        <location filename="../src/oauthwizard.cpp" line="130"/>
        <source>Authorise Pumpa</source>
        <translation>Pumpa autorisieren</translation>
    </message>
    <message>
        <location filename="../src/oauthwizard.cpp" line="135"/>
        <source>In order for Pumpa to be able to read and post new messages to your pump.io account you need to grant Pumpa access via the web page. Pumpa will open the web page for you - just follow the instructions and copy &amp;amp; paste the &lt;b&gt;verifier&lt;/b&gt; text string back into the field below. (The token should be automatically pre-filled.)</source>
        <translation>Damit Pumpa neue Nachrichten lesen und veröffentlichen kann, müssen Sie den Zugriff auf Ihr pump.io-Konto gestatten. Pumpa wird dazu eine Webseite des pump.io-Servers aufrufen, deren Anweisungen Sie folgen. Um den Anmeldevorgang abzuschließen, kopieren Sie den &lt;b&gt;Verifier&lt;/b&gt; in das Feld unten. (Der &quot;Token&quot; sollte von Pumpa automatisch eingetragen werden, sobald sich die Webseite öffnet.)</translation>
    </message>
    <message>
        <location filename="../src/oauthwizard.cpp" line="145"/>
        <source>Token:</source>
        <translation>Token:</translation>
    </message>
    <message>
        <location filename="../src/oauthwizard.cpp" line="151"/>
        <source>Verifier:</source>
        <translation>Verifier:</translation>
    </message>
</context>
<context>
    <name>OAuthWizard</name>
    <message>
        <location filename="../src/oauthwizard.cpp" line="226"/>
        <source>Registering client ...</source>
        <translation>Registriere Client ...</translation>
    </message>
    <message>
        <location filename="../src/oauthwizard.cpp" line="257"/>
        <source>Network error: </source>
        <translation>Netzwerkfehler: </translation>
    </message>
    <message>
        <location filename="../src/oauthwizard.cpp" line="269"/>
        <source>Registered client to [%1] successfully.</source>
        <translation>Anmeldung des Clients an [%1] erfolgreich.</translation>
    </message>
    <message>
        <location filename="../src/oauthwizard.cpp" line="278"/>
        <source>Authorising user ...</source>
        <translation>Autorisiere Benutzer ...</translation>
    </message>
    <message>
        <location filename="../src/oauthwizard.cpp" line="302"/>
        <source>Network or authentication error!</source>
        <translation>Netzwerk- oder Autorisierungsfehler!</translation>
    </message>
</context>
<context>
    <name>ObjectWidget</name>
    <message>
        <location filename="../src/objectwidget.cpp" line="178"/>
        <source>Re: </source>
        <translation>Aw: </translation>
    </message>
    <message>
        <location filename="../src/objectwidget.cpp" line="179"/>
        <source>show context</source>
        <translation>Kontext anzeigen</translation>
    </message>
</context>
<context>
    <name>PumpApp</name>
    <message>
        <location filename="../src/pumpapp.cpp" line="160"/>
        <source>&amp;Inbox</source>
        <translation type="unfinished">E&amp;ingang</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="161"/>
        <source>&amp;Mentions</source>
        <translation>&amp;Erwähnungen</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="162"/>
        <source>&amp;Direct</source>
        <translation type="unfinished">&amp;Direkt</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="163"/>
        <source>Mean&amp;while</source>
        <translation type="unfinished">Inz&amp;wischen</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/pumpapp.cpp" line="494"/>
        <source>You have %Ln new notification(s).</source>
        <translation>
            <numerusform>Sie haben %n neue Benachrichtigung.</numerusform>
            <numerusform>Sie haben %n neue Benachrichtigungen.</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="806"/>
        <source>Copyright &amp;copy; 2013-2015 Mats Sj&amp;ouml;berg</source>
        <translation>Copyright &amp;copy; 2013-2015 Mats Sj&amp;ouml;berg</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1154"/>
        <source>Fi&amp;rehose</source>
        <translation type="unfinished">Fi&amp;rehose</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="579"/>
        <source>Error: </source>
        <translation>Fehler: </translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="638"/>
        <source>%1 &amp;Window</source>
        <translation>%1 &amp;Fenster</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="638"/>
        <source>Hide</source>
        <translation>Verstecken</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="638"/>
        <source>Show</source>
        <translation>Anzeigen</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="653"/>
        <source>E&amp;xit</source>
        <translation type="unfinished">&amp;Verlassen</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="654"/>
        <source>Ctrl+Q</source>
        <translation>Strg+Q</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="657"/>
        <source>Preferences</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="660"/>
        <source>&amp;Reload timeline</source>
        <translation>Beit&amp;räge neu laden</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="661"/>
        <source>Ctrl+R</source>
        <translation type="unfinished">Strg+R</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="665"/>
        <source>Load older in timeline</source>
        <translation>Ältere Beiträge laden</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="666"/>
        <source>Ctrl+O</source>
        <translation type="unfinished">Strg+L</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="669"/>
        <source>F&amp;ollow an account</source>
        <translation>Nutzer f&amp;olgen</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="670"/>
        <source>Ctrl+L</source>
        <translation type="unfinished">Strg+F</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="676"/>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="679"/>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="685"/>
        <source>New &amp;Note</source>
        <translation>&amp;Neue Mitteilung</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="686"/>
        <source>Ctrl+N</source>
        <translation>Strg+N</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="690"/>
        <source>Ctrl+D</source>
        <translation>Strg+D</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="314"/>
        <location filename="../src/pumpapp.cpp" line="702"/>
        <source>Followers</source>
        <translation type="unfinished">Verfolger</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="250"/>
        <source>SSL Error: </source>
        <translation>SSL-Fehler: </translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="253"/>
        <source>
%1 is unable to verify the identity of the server. This error could mean that someone is trying to impersonate the server, or that the server&apos;s administrator has made an error.
</source>
        <translation>
%1 ist nicht in der Lage, die Identität des Servers zu überprüfen. Dieser Fehler könnte bedeuten, dass jemand versucht sich als dieser Server auszugeben, oder dass der Server-Administrator einen Fehler gemacht hat.</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="261"/>
        <source>SSL Server certificate.
</source>
        <translation>SSL-Server-Zertifkat.</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="262"/>
        <source>Issued to: </source>
        <translation>Ausgestellt für: </translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="263"/>
        <source>Issued by: </source>
        <translation>Herausgegeben von:</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="264"/>
        <source>Effective: </source>
        <translation type="unfinished">Wirksam: </translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="265"/>
        <source>Expires: </source>
        <translation type="unfinished">Verfällt: </translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="266"/>
        <source>MD5 digest: </source>
        <translation>MD5-Hashwert: </translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="273"/>
        <source>&lt;b&gt;Untrusted SSL connection!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Nicht vertrauenswürdige SSL-Verbindung!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="831"/>
        <source>Public</source>
        <translation>Öffentlich</translation>
    </message>
    <message>
        <source>You have %1 new notifications.</source>
        <translation type="obsolete">Sie habe %1 neue Benachrichtigung.</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="504"/>
        <source>%1 commented: </source>
        <translation>%1 kommentierte: </translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="506"/>
        <source>%1 wrote: </source>
        <translation>%1 schrieb: </translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="673"/>
        <source>Your &amp;profile</source>
        <translation>Ihr &amp;Profil</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="682"/>
        <source>Report &amp;bug online</source>
        <translation>Programm&amp;fehler online melden</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="694"/>
        <source>Close tab</source>
        <translation>Reiter schließen</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="695"/>
        <source>Ctrl+W</source>
        <translation>Strg+W</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="699"/>
        <source>Firehose</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="705"/>
        <source>Following</source>
        <translation type="unfinished">Verfolgte</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="708"/>
        <source>Favorites</source>
        <translation>Favoriten</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="712"/>
        <source>Activities</source>
        <translation>Aktivitäten</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="723"/>
        <source>&amp;Pumpa</source>
        <translation>&amp;Pumpa</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="736"/>
        <source>&amp;Tabs</source>
        <translation>&amp;Reiter</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="745"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="777"/>
        <source>&lt;p&gt;Pumpa is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.&lt;/p&gt;&lt;p&gt;Pumpa is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/p&gt;&lt;p&gt;You should have received a copy of the GNU General Public License along with Pumpa.  If not, see &lt;a href=&quot;http://www.gnu.org/licenses/&quot;&gt;http://www.gnu.org/licenses/&lt;/a&gt;.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Pumpa ist freie Software: Sie können es weiterverbreiten und/oder verändern unter den Bedingungen der &apos;GNU General Public License&apos;, wie sie von der &apos;Free Software Foundation&apos; in Version 3 oder (nach ihrer Wahl) einer späteren Version veröffentlicht wurde.&lt;/p&gt;&lt;p&gt;Pumpa wird in der Hoffnung verbreitet, dass es nützlich sei, jedoch OHNE JEGLICHE GEWÄHRLEISTUNG; auch ohne eine inbegriffene MARKTGÄNGIKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK. Wenden Sie sich an die&apos;GNU General Public License&apos; für weitere Details.&lt;/p&gt;&lt;p&gt;Sie sollten eine Kopie der &apos;GNU General Public License&apos; zusamment mit Pumpa erhalten haben. Andernfalls, schauen Sie auf &lt;a href=&quot;http://www.gnu.org/licenses/&quot;&gt;http://www.gnu.org/licenses/&lt;/a&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="790"/>
        <source>&lt;p&gt;The &lt;a href=&quot;https://github.com/kypeli/kQOAuth&quot;&gt;kQOAuth library&lt;/a&gt; is copyrighted by &lt;a href=&quot;http://www.johanpaul.com/&quot;&gt;Johan Paul&lt;/a&gt; and licensed under LGPL 2.1.&lt;/p&gt;&lt;p&gt;The &lt;a href=&quot;https://github.com/vmg/sundown&quot;&gt;sundown Markdown library&lt;/a&gt; is copyrighted by Natacha Port&amp;eacute;, Vicent Marti and others, and &lt;a href=&quot;https://github.com/vmg/sundown#license&quot;&gt;permissively licensed&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;The Pumpa logo was &lt;a href=&quot;http://opengameart.org/content/fruit-and-veggie-inventory&quot;&gt;created by Joshua Taylor&lt;/a&gt; for the &lt;a href=&quot;http://lpc.opengameart.org/&quot;&gt;Liberated Pixel Cup&lt;/a&gt;.The logo is copyrighted by the artist and is dual licensed under the CC-BY-SA 3.0 license and the GNU GPL 3.0.</source>
        <translation>&lt;p&gt;Die&lt;a href=&quot;https://github.com/kypeli/kQOAuth&quot;&gt;kQOAuth-Bibliothek&lt;/a&gt; hat das Copyright von &lt;a href=&quot;http://www.johanpaul.com/&quot;&gt;Johan Paul&lt;/a&gt; und ist unter LGPL 2.1 lizensiert.&lt;/p&gt;&lt;p&gt;Die &lt;a href=&quot;https://github.com/vmg/sundown&quot;&gt;sundown-Markdown-Bibliothek&lt;/a&gt; hat das Copyright von Natacha Port&amp;eacute;, Vicent Marti und anderen, und ist &lt;a href=&quot;https://github.com/vmg/sundown#license&quot;&gt;großzügig lizensiert&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;Das Pumpa-Logo wurde &lt;a href=&quot;http://opengameart.org/content/fruit-and-veggie-inventory&quot;&gt;von Joshua Taylor entworfen&lt;/a&gt; für den &lt;a href=&quot;http://lpc.opengameart.org/&quot;&gt;Liberated-Pixel-Cup&lt;/a&gt;.Das Logo hat das Copyright des Künstlers und ist dopppelt unter der CC-BY-SA 3.0-Lizenz und der GNU GPL 3.0 lizensiert.</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="809"/>
        <source>&lt;p&gt;Report bugs and feature requests at &lt;a href=&quot;%5&quot;&gt;%5&lt;/a&gt;.&lt;/p&gt;</source>
        <translation>&lt;p&gt; Fehler und Verbesserungsvorschläge bitte an &lt;a href=&quot;%5&quot;&gt;%5&lt;/a&gt; melden!&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="813"/>
        <source>A simple Qt-based pump.io client.</source>
        <translation>Ein einfacher Qt-basierter pump.io-Client.</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="817"/>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="934"/>
        <source>Site not configured yet!</source>
        <translation>Seite ist noch nicht konfiguriert!</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="984"/>
        <source>Follow pump.io user</source>
        <translation>pump.io Nutzer folgen</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="985"/>
        <source>Enter webfinger ID of person to follow: </source>
        <translation>Geben Sie die Webfinger-ID der Person ein, der Sie folgen wollen: </translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="995"/>
        <source>Sorry, that doesn&apos;t even look like a webfinger ID!</source>
        <translation>Entschuldigung, aber das sieht leider nicht wie eine Webfinger-ID aus!</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1000"/>
        <source>Sorry, you are already following that person!</source>
        <translation>Entschuldigung, Sie folgen dieser Person bereits!</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1098"/>
        <source>Invalid user: </source>
        <translation>Ungültiger Benutzer: </translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1105"/>
        <source>Invalid user (cannot check site): </source>
        <translation>Ungültiger Benutzer (Seite kann nicht überprüft werden): </translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1130"/>
        <source>&amp;Context</source>
        <translation>&amp;Kontext</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1163"/>
        <source>&amp;Followers</source>
        <translation>Ver&amp;folger</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1172"/>
        <source>F&amp;ollowing</source>
        <translation>F&amp;olge</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1181"/>
        <source>F&amp;avorites</source>
        <translation>Fa&amp;voriten</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1190"/>
        <source>A&amp;ctivities</source>
        <translation>&amp;Aktivitäten</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1528"/>
        <source>Loading ...</source>
        <translation>Lade ...</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1590"/>
        <source>Ready!</source>
        <translation>Bereit!</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1608"/>
        <source>Unable to post message!</source>
        <translation>Nachricht kann nicht veröffentlicht werden!</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1612"/>
        <source>Unable to upload image!</source>
        <translation>Bild kann nicht hochgeladen werden!</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1616"/>
        <source>Network or authorisation error [%1/%2] %3.</source>
        <translation>Netzwerk- oder Autorisierungsfehler! [%1/%2] %3.</translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1655"/>
        <source>Successfully followed </source>
        <translation>Du folgst jetzt </translation>
    </message>
    <message>
        <location filename="../src/pumpapp.cpp" line="1656"/>
        <source>Successfully unfollowed </source>
        <translation>Entfolgen erfolgreich </translation>
    </message>
</context>
<context>
    <name>PumpaSettingsDialog</name>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="34"/>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="37"/>
        <source>Not logged in currently.</source>
        <translation>Zur Zeit nicht eingeloggt.</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="40"/>
        <source>Change account</source>
        <translation>Konto wechseln</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="45"/>
        <source>Clicking &quot;Change account&quot; will run the authentication setup again for a new pump.io account. This will remove the current login credentials since Pumpa only supports one account at a time.</source>
        <translation>Wenn sie auf &quot;Konto wechseln&quot; klicken, wird der Authentifizierungsprozess neu gestartet. Alle Anmeldedaten zu Ihrem pump.io-Konto werden vom System entfernt. Mit Pumpa können zur Zeit nicht mehrere Konten gleichzeitig genutzt werden.</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="56"/>
        <source>Interface</source>
        <translation>Benutzeroberfläche</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="63"/>
        <source>Update interval (in minutes):</source>
        <translation>Aktualisierungsintervall (in Minuten):</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="68"/>
        <source>Public</source>
        <translation>Öffentlich</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="69"/>
        <source>Followers</source>
        <translation type="unfinished">Verfolger</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="73"/>
        <source>Default &quot;To&quot;:</source>
        <translation>Standardempfänger für &quot;An&quot;:</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="77"/>
        <source>Default &quot;CC&quot;:</source>
        <translation>Standardempfänger für &quot;CC&quot;:</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="79"/>
        <source>Use icon in system tray</source>
        <translation>Icon in der Statusleiste anzeigen</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="82"/>
        <source>Show message character count</source>
        <translation>Zeige Zeichenanzahl von Nachrichten an</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="88"/>
        <source>Notifications</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="92"/>
        <source>Never</source>
        <translation>Niemals</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="93"/>
        <source>Direct only</source>
        <translation>Nur direkt</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="94"/>
        <source>Direct or mention</source>
        <translation>Direkt oder Erwähnung</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="95"/>
        <source>Direct, mention or inbox</source>
        <translation>Direkt, Erwähnung oder aus dem Eingang</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="96"/>
        <source>Anything</source>
        <translation>Irgendetwas</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="100"/>
        <source>Highlight tray icon on:</source>
        <translation>Icon in der Statusleiste hervorheben wenn:</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="104"/>
        <source>Popup notification on:</source>
        <translation>Popup-Benachrichtigungen bei:</translation>
    </message>
    <message>
        <location filename="../src/pumpasettingsdialog.cpp" line="163"/>
        <source>Currently logged in as %1.</source>
        <translation>Zur Zeit eingeloggt als: %1.</translation>
    </message>
</context>
<context>
    <name>QASObject</name>
    <message>
        <location filename="../src/qasobject.cpp" line="320"/>
        <source>Deleted %1</source>
        <translation>Gelöscht am %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/util.cpp" line="160"/>
        <source>a few seconds ago</source>
        <translation>vor ein paar Sekunden</translation>
    </message>
    <message>
        <location filename="../src/util.cpp" line="162"/>
        <source>one minute ago</source>
        <translation>vor einer Minute</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/util.cpp" line="164"/>
        <source>%n minutes ago</source>
        <translation>
            <numerusform>vor %n Minute</numerusform>
            <numerusform>vor %n Minuten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/util.cpp" line="166"/>
        <source>one hour ago</source>
        <translation>
            <numerusform>vor einer Stunde</numerusform>
            <numerusform>vor einer Stunde</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/util.cpp" line="168"/>
        <source>%n hours ago</source>
        <translation>
            <numerusform>vor %n Stunden</numerusform>
            <numerusform>vor %n Stunden</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/util.cpp" line="171"/>
        <source>one day ago</source>
        <translation>
            <numerusform>vor einem Tag</numerusform>
            <numerusform>vor einem Tag</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/util.cpp" line="173"/>
        <source>%n days ago</source>
        <translation>
            <numerusform>vor %n Tagen</numerusform>
            <numerusform>vor %n Tagen</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/util.cpp" line="175"/>
        <source>one week ago</source>
        <translation>
            <numerusform>vor einer Woche</numerusform>
            <numerusform>vor einer Woche</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/util.cpp" line="177"/>
        <source>%n weeks ago</source>
        <translation>
            <numerusform>vor %n Wochen</numerusform>
            <numerusform>vor %n Wochen</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/util.cpp" line="179"/>
        <source>one month ago</source>
        <translation>
            <numerusform>vor einem Monat</numerusform>
            <numerusform>vor einem Monat</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/util.cpp" line="181"/>
        <source>%n months ago</source>
        <translation>
            <numerusform>vor %n Monaten</numerusform>
            <numerusform>vor %n Monaten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/util.cpp" line="183"/>
        <source>one year ago</source>
        <translation>
            <numerusform>vor einem Jahr</numerusform>
            <numerusform>vor einem Jahr</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/util.cpp" line="185"/>
        <source>%n years ago</source>
        <translation>
            <numerusform>vor %n Jahren</numerusform>
            <numerusform>vor %n Jahren</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="obsolete">
            <numerusform>vor %n Minute</numerusform>
            <numerusform>vor %n Minuten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="obsolete">
            <numerusform>vor %n Stunde</numerusform>
            <numerusform>vor %n Stunden</numerusform>
        </translation>
    </message>
</context>
</TS>
